import java.sql.DatabaseMetaData;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

import junit.framework.TestCase;

public abstract class BaseTests extends TestCase {
	MayBMS maybms=new MayBMS();
	boolean connected=false;
	
	@Override
	protected void setUp() throws Exception {
		super.setUp();
		try {
			maybms.connectToMayBMS(getDatabase());
			dropAllTablesExceptUseful();
			maybms.db.createStatement().execute("SET statement_timeout TO 1000");
			connected = true;
		} catch (SQLException e) {
			System.err.println(e.getMessage());
			connected = false;
		}
	}

	@Override
	protected void tearDown() throws Exception {
		super.tearDown();
		maybms.closeConnection();
	}
	
	public void dropAllTablesExceptUseful() throws SQLException
	{
		String tab[]={"claims","trust","relevant","claimsp","trustp","relevantp"};
		Set<String> s=new HashSet<String>(Arrays.asList(tab));
		
		DatabaseMetaData dm = maybms.db.getMetaData();
		String[] types={"TABLE"};
		ResultSet rs=dm.getTables(null, null, "%", types);
		while(rs.next())
		{
			String table = rs.getString(3);
			if(!s.contains(table)) {
				maybms.sendQuery("DROP TABLE "+table);
			}
		}
	}
	
	abstract String getDatabase();
}