import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.Map;
import java.util.Set;

/**
 * This class contains the public test cases for the project. The public tests
 * are distributed with the project description, and students can run the public
 * tests themselves against their own implementation.
 * 
 * Any changes to this file will be ignored when testing your project.
 * 
 */
public class PublicTests extends BaseTests {
	@Override
	String getDatabase() {
		return MayBMS.getLogin();
	}
	
	public void testSendQuery() {
		assertTrue(connected);
		try {
			ResultSet rs = maybms.sendQuery("SELECT 2+2");
		    assertTrue(rs.next());
		    assertEquals(rs.getInt(1),4);
		} catch(SQLException e) {
			fail(e.getMessage());
		}
	}
	
	public void testGetSources() {
		assertTrue(connected);
		try {
			Set<String> sources = maybms.getSources();
			assertEquals(sources.size(),4);
			assertTrue(sources.contains("Legifrance"));
			assertFalse(sources.contains("Blabla"));
		} catch (SQLException e) {
			fail(e.getMessage());
		}
	}
	
	public void testGetTrustworthySources() {
		assertTrue(connected);
		try {
			Map<String,Double> sources = maybms.getTrustworthySources();
			assertEquals(sources.size(),4);
			assertEquals(0.192, sources.get("Gorafi"), 0.001);
			assertEquals(0.16, sources.get("Doctissimo"), 0.001);
		} catch (SQLException e) {
			fail(e.getMessage());
		}
	}

	public void testGetTrustworthySourcesMayBMS() {
		assertTrue(connected);
		try {
			Map<String,Double> sources = maybms.getTrustworthySourcesMayBMS();
			assertEquals(sources.size(),4);
			assertEquals(0.192, sources.get("Gorafi"), 0.001);
			assertEquals(0.16, sources.get("Doctissimo"), 0.001);
		} catch (SQLException e) {
			fail(e.getMessage());
		}
	}
	
	public void testGetClaimsTwoDifferentTrustworthySourcesMayBMS() {
		assertTrue(connected);
		try {
			Map<Integer,Double> claims = maybms.getClaimsTwoDifferentTrustworthySourcesMayBMS();
			assertEquals(claims.size(),3);
			assertEquals(0.530, claims.get(42), 0.001);
			assertEquals(0.090, claims.get(51), 0.001);
		} catch (SQLException e) {
			fail(e.getMessage());
		}
	}

	public void testIsTrustworthySourceMakesRelevantClaim() {
		assertTrue(connected);
		try {
			double result = maybms.isTrustworthySourceMakesRelevantClaimMayBMS();
			assertEquals(0.563,result,0.001);
		} catch (SQLException e) {
			fail(e.getMessage());
		}
	}
	
	public void testIsTrustworthySourceMakesRelevantClaim2() {
		assertTrue(connected);
		try {
			double result = maybms.isTrustworthySourceMakesRelevantClaim2MayBMS();
			assertTrue(Math.abs(result-0.563471)>1e-4);
			assertEquals(result,0.563,0.05);
		} catch (SQLException e) {
			fail(e.getMessage());
		}
	}
}